#[non_exhaustive]pub enum EventLogError {
InvalidRead {
detail: String,
},
CrossSessionCursor {
detail: String,
},
IncompatibleCursor {
detail: String,
},
ExpiredCursor {
detail: String,
},
InvalidAppend {
detail: String,
},
Corruption {
detail: String,
},
Backend {
detail: String,
},
}Expand description
Errors from canonical event append or bounded replay.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidRead
A cursor, snapshot, session binding, or limit was invalid.
CrossSessionCursor
A cursor was presented for a different session.
IncompatibleCursor
A cursor’s position and stable snapshot are internally inconsistent.
ExpiredCursor
The cursor references a snapshot no longer available from this reader.
InvalidAppend
The request cannot be appended to a durable log.
Corruption
Persisted canonical envelopes conflict or are malformed.
Backend
The storage backend failed.