pub struct HarnessBuilder { /* private fields */ }Expand description
Implementations
Sourceimpl HarnessBuilder
impl HarnessBuilder
Sourcepub fn new(
name: impl Into<String>,
system_prompt: impl Into<String>,
) -> HarnessBuilder
pub fn new( name: impl Into<String>, system_prompt: impl Into<String>, ) -> HarnessBuilder
Create a harness builder from the required embedder-facing fields.
Sourcepub fn id(self, id: TypedId<HarnessIdMarker>) -> HarnessBuilder
pub fn id(self, id: TypedId<HarnessIdMarker>) -> HarnessBuilder
Set a stable harness id instead of generating one.
Sourcepub fn harness_id(&self) -> TypedId<HarnessIdMarker>
pub fn harness_id(&self) -> TypedId<HarnessIdMarker>
Return the id currently assigned to this builder.
pub fn name(self, name: impl Into<String>) -> HarnessBuilder
pub fn display_name(self, display_name: impl Into<String>) -> HarnessBuilder
pub fn description(self, description: impl Into<String>) -> HarnessBuilder
pub fn system_prompt(self, system_prompt: impl Into<String>) -> HarnessBuilder
pub fn parent_harness_id( self, parent_harness_id: TypedId<HarnessIdMarker>, ) -> HarnessBuilder
pub fn default_model_id( self, default_model_id: TypedId<ModelIdMarker>, ) -> HarnessBuilder
pub fn tag(self, tag: impl Into<String>) -> HarnessBuilder
pub fn capability( self, capability: impl Into<AgentCapabilityConfig>, ) -> HarnessBuilder
pub fn with_capability( self, capability: impl Into<AgentCapabilityConfig>, ) -> HarnessBuilder
pub fn capabilities<I, C>(self, capabilities: I) -> HarnessBuilder
pub fn initial_file(self, file: InitialFile) -> HarnessBuilder
pub fn network_access(self, network_access: NetworkAccessList) -> HarnessBuilder
Sourcepub fn parallel_tool_calls(self, parallel_tool_calls: bool) -> HarnessBuilder
pub fn parallel_tool_calls(self, parallel_tool_calls: bool) -> HarnessBuilder
Set the request-level parallel tool calling preference (EVE-598).
pub fn mcp_servers( self, mcp_servers: BTreeMap<String, ScopedMcpServer>, ) -> HarnessBuilder
pub fn metadata_entry( self, key: impl Into<String>, value: impl Into<String>, ) -> HarnessBuilder
pub fn metadata_entries<I, K, V>(self, entries: I) -> HarnessBuilder
Sourcepub fn openrouter_attribution(
self,
http_referer: impl Into<String>,
title: impl Into<String>,
) -> HarnessBuilder
pub fn openrouter_attribution( self, http_referer: impl Into<String>, title: impl Into<String>, ) -> HarnessBuilder
Set OpenRouter attribution headers for LLM calls made by this harness.
The values flow through harness embedder metadata and are sent by the
OpenRouter driver as HTTP-Referer and X-Title.
pub fn is_built_in(self, is_built_in: bool) -> HarnessBuilder
pub fn status(self, status: HarnessStatus) -> HarnessBuilder
pub fn created_at(self, created_at: DateTime<Utc>) -> HarnessBuilder
pub fn updated_at(self, updated_at: DateTime<Utc>) -> HarnessBuilder