pub struct SessionBuilder { /* private fields */ }Expand description
Builds a Session with runtime-friendly defaults.
Implementations
Sourceimpl SessionBuilder
impl SessionBuilder
Sourcepub fn new(harness_id: TypedId<HarnessIdMarker>) -> SessionBuilder
pub fn new(harness_id: TypedId<HarnessIdMarker>) -> SessionBuilder
Create a session builder for the required harness id.
Sourcepub fn id(self, id: TypedId<SessionIdMarker>) -> SessionBuilder
pub fn id(self, id: TypedId<SessionIdMarker>) -> SessionBuilder
Set a stable session id instead of generating one.
Sourcepub fn session_id(&self) -> TypedId<SessionIdMarker>
pub fn session_id(&self) -> TypedId<SessionIdMarker>
Return the id currently assigned to this builder.
pub fn organization_id( self, organization_id: impl Into<String>, ) -> SessionBuilder
pub fn harness(self, harness_id: TypedId<HarnessIdMarker>) -> SessionBuilder
pub fn agent(self, agent_id: TypedId<AgentIdMarker>) -> SessionBuilder
pub fn owner_principal_id( self, owner_principal_id: TypedId<PrincipalIdMarker>, ) -> SessionBuilder
pub fn title(self, title: impl Into<String>) -> SessionBuilder
pub fn goal(self, goal: impl Into<String>) -> SessionBuilder
pub fn locale(self, locale: impl Into<String>) -> SessionBuilder
pub fn tag(self, tag: impl Into<String>) -> SessionBuilder
pub fn model_id(self, model_id: TypedId<ModelIdMarker>) -> SessionBuilder
pub fn capability( self, capability: impl Into<AgentCapabilityConfig>, ) -> SessionBuilder
pub fn with_capability( self, capability: impl Into<AgentCapabilityConfig>, ) -> SessionBuilder
pub fn capabilities<I, C>(self, capabilities: I) -> SessionBuilder
pub fn tool(self, tool: ToolDefinition) -> SessionBuilder
pub fn tools<I>(self, tools: I) -> SessionBuilderwhere
I: IntoIterator<Item = ToolDefinition>,
pub fn mcp_servers( self, mcp_servers: BTreeMap<String, ScopedMcpServer>, ) -> SessionBuilder
pub fn system_prompt(self, system_prompt: impl Into<String>) -> SessionBuilder
pub fn initial_file(self, file: InitialFile) -> SessionBuilder
pub fn network_access(self, network_access: NetworkAccessList) -> SessionBuilder
pub fn max_iterations(self, max_iterations: usize) -> SessionBuilder
Sourcepub fn parallel_tool_calls(self, parallel_tool_calls: bool) -> SessionBuilder
pub fn parallel_tool_calls(self, parallel_tool_calls: bool) -> SessionBuilder
Set the request-level parallel tool calling preference (EVE-598).
pub fn status(self, status: SessionStatus) -> SessionBuilder
pub fn created_at(self, created_at: DateTime<Utc>) -> SessionBuilder
pub fn updated_at(self, updated_at: DateTime<Utc>) -> SessionBuilder