PlatformStoreFactory

Type Alias PlatformStoreFactory 

pub type PlatformStoreFactory = Arc<dyn Fn(i64, TypedId<SessionIdMarker>) -> Arc<dyn PlatformStore> + Sync + Send>;
Factory producing a per-(org, session) PlatformStore. The session id is supplied because platform stores are scoped to the calling session for subagent spawning and platform-management tools.

Aliased Type

pub struct PlatformStoreFactory { /* private fields */ }